@@ -37,8 +37,16 @@ pub struct InteractionChannel {
 
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub struct InteractionMember {
+    /// Member's guild avatar.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub avatar: Option<String>,
     pub joined_at: Timestamp,
     pub nick: Option<String>,
+    /// Whether the user has yet to pass the guild's Membership Screening
+    /// requirements.
+    pub pending: bool,
+    /// Total permissions of the member in this channel including overwrites
+    pub permissions: Permissions,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub premium_since: Option<Timestamp>,
     #[serde(default)]
@@ -86,8 +94,11 @@ mod tests {
             members: IntoIterator::into_iter([(
                 UserId::new(300).expect("non zero"),
                 InteractionMember {
+                    avatar: None,
                     joined_at,
                     nick: None,
+                    pending: false,
+                    permissions: Permissions::empty(),
                     premium_since: None,
                     roles: Vec::new(),
                 },
@@ -232,12 +243,16 @@ mod tests {
                 Token::Str("300"),
                 Token::Struct {
                     name: "InteractionMember",
-                    len: 3,
+                    len: 5,
                 },
                 Token::Str("joined_at"),
                 Token::Str("2021-08-10T12:18:37.000000+00:00"),
                 Token::Str("nick"),
                 Token::None,
+                Token::Str("pending"),
+                Token::Bool(false),
+                Token::Str("permissions"),
+                Token::Str("0"),
                 Token::Str("roles"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
