@@ -356,8 +356,11 @@ mod test {
                     members: IntoIterator::into_iter([(
                         UserId::new(600).expect("non zero"),
                         InteractionMember {
+                            avatar: None,
                             joined_at,
                             nick: Some("nickname".into()),
+                            pending: false,
+                            permissions: Permissions::empty(),
                             premium_since: None,
                             roles: Vec::new(),
                         },
@@ -474,13 +477,17 @@ mod test {
                 Token::Str("600"),
                 Token::Struct {
                     name: "InteractionMember",
-                    len: 3,
+                    len: 5,
                 },
                 Token::Str("joined_at"),
                 Token::Str("2020-01-01T00:00:00.000000+00:00"),
                 Token::Str("nick"),
                 Token::Some,
                 Token::Str("nickname"),
+                Token::Str("pending"),
+                Token::Bool(false),
+                Token::Str("permissions"),
+                Token::Str("0"),
                 Token::Str("roles"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
